@@ -9,14 +9,18 @@ from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
 from braintree.credit_card import CreditCard
 from braintree.paypal_account import PayPalAccount
 from braintree.europe_bank_account import EuropeBankAccount
+from braintree.us_bank_account import UsBankAccount
 from braintree.coinbase_account import CoinbaseAccount
 from braintree.venmo_account import VenmoAccount
+from braintree.visa_checkout_card import VisaCheckoutCard
+from braintree.masterpass_card import MasterpassCard
 from braintree.address import Address
 from braintree.configuration import Configuration
 from braintree.ids_search import IdsSearch
 from braintree.exceptions.not_found_error import NotFoundError
 from braintree.resource_collection import ResourceCollection
 from braintree.transparent_redirect import TransparentRedirect
+from braintree.samsung_pay_card import SamsungPayCard
 
 class Customer(Resource):
     """
@@ -51,7 +55,8 @@ class Customer(Resource):
                     "country_name": "United States of America"
                 },
                 "options": {
-                    "verify_card": True
+                    "verify_card": True,
+                    "verification_amount": "2.00"
                 }
             },
             "custom_fields": {
@@ -62,12 +67,25 @@ class Customer(Resource):
         print(result.customer.id)
         print(result.customer.first_name)
 
-    For more information on Customers, see https://developers.braintreepayments.com/ios+python/reference/request/customer/create
+    For more information on Customers, see https://developers.braintreepayments.com/reference/request/customer/create/python
 
     """
 
     def __repr__(self):
-        detail_list = ["first_name", "last_name", "id"]
+        detail_list = [
+            "id",
+            "company",
+            "created_at",
+            "email",
+            "fax",
+            "first_name",
+            "last_name",
+            "merchant_id",
+            "phone",
+            "updated_at",
+            "website",
+        ]
+
         return super(Customer, self).__repr__(detail_list)
 
     @staticmethod
@@ -117,7 +135,7 @@ class Customer(Resource):
         return Configuration.gateway().customer.delete(customer_id)
 
     @staticmethod
-    def find(customer_id):
+    def find(customer_id, association_filter_id=None):
         """
         Find an customer, given a customer_id.  This does not return a result
         object.  This will raise a :class:`NotFoundError <braintree.exceptions.not_found_error.NotFoundError>` if the provided customer_id
@@ -126,7 +144,7 @@ class Customer(Resource):
             customer = braintree.Customer.find("my_customer_id")
         """
 
-        return Configuration.gateway().customer.find(customer_id)
+        return Configuration.gateway().customer.find(customer_id, association_filter_id)
 
     @staticmethod
     def search(*query):
@@ -177,16 +195,33 @@ class Customer(Resource):
     def create_signature():
         return [
             "company", "email", "fax", "first_name", "id", "last_name", "phone", "website", "device_data", "device_session_id", "fraud_merchant_id", "payment_method_nonce",
+            {"risk_data": ["customer_browser", "customer_ip"]},
             {"credit_card": CreditCard.create_signature()},
-            {"custom_fields": ["__any_key__"]}
+            {"custom_fields": ["__any_key__"]},
+            {"options": [{"paypal": [
+                "payee_email",
+                "order_id",
+                "custom_field",
+                "description",
+                "amount",
+                { "shipping": Address.create_signature() }
+            ]}]},
         ]
 
     @staticmethod
     def update_signature():
         return [
-            "company", "email", "fax", "first_name", "id", "last_name", "phone", "website", "device_data", "device_session_id", "fraud_merchant_id", "payment_method_nonce",
+            "company", "email", "fax", "first_name", "id", "last_name", "phone", "website", "device_data", "device_session_id", "fraud_merchant_id", "payment_method_nonce", "default_payment_method_token",
             {"credit_card": CreditCard.signature("update_via_customer")},
-            {"custom_fields": ["__any_key__"]}
+            {"custom_fields": ["__any_key__"]},
+            {"options": [{"paypal": [
+                "payee_email",
+                "order_id",
+                "custom_field",
+                "description",
+                "amount",
+                { "shipping": Address.create_signature() }
+            ]}]},
         ]
 
     def __init__(self, gateway, attributes):
@@ -227,3 +262,18 @@ class Customer(Resource):
             self.venmo_accounts = [VenmoAccount(gateway, venmo_account) for venmo_account in self.venmo_accounts]
             self.payment_methods += self.venmo_accounts
 
+        if "us_bank_accounts" in attributes:
+            self.us_bank_accounts = [UsBankAccount(gateway, us_bank_account) for us_bank_account in self.us_bank_accounts]
+            self.payment_methods += self.us_bank_accounts
+
+        if "visa_checkout_cards" in attributes:
+            self.visa_checkout_cards = [VisaCheckoutCard(gateway, visa_checkout_card) for visa_checkout_card in self.visa_checkout_cards]
+            self.payment_methods += self.visa_checkout_cards
+
+        if "masterpass_cards" in attributes:
+            self.masterpass_cards = [MasterpassCard(gateway, masterpass_card) for masterpass_card in self.masterpass_cards]
+            self.payment_methods += self.masterpass_cards
+
+        if "samsung_pay_cards" in attributes:
+            self.samsung_pay_cards = [SamsungPayCard(gateway, samsung_pay_card) for samsung_pay_card in self.samsung_pay_cards]
+            self.payment_methods += self.samsung_pay_cards
