@@ -32,6 +32,7 @@ class ErrorCodes(object):
         PostalCodeInvalidCharacters = "81813"
         PostalCodeIsInvalid = "91826"
         PostalCodeIsRequired = "81808"
+        PostalCodeIsRequiredForCardBrandAndProcessor = "81828"
         PostalCodeIsTooLong = "81809"
         RegionIsInvalid = "91825"
         RegionIsTooLong = "81810"
@@ -129,6 +130,8 @@ class ErrorCodes(object):
         TokenIsTooLong = "91720"
         VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted = "91726"
         VerificationNotSupportedOnThisMerchantAccount = "91730"
+        VerificationAccountTypeIsInvald = "91757"
+        VerificationAccountTypeNotSupported = "91758"
 
         class Options(object):
             UpdateExistingTokenIsInvalid = "91723"
@@ -202,6 +205,7 @@ class ErrorCodes(object):
         FileIsTooLarge = "84902"
         FileTypeIsInvalid = "84903"
         FileIsMalformedOrEncrypted = "84904"
+        FileIsTooLong = "84905"
 
     class Merchant(object):
         CountryCannotBeBlank = "83603"
@@ -342,6 +346,8 @@ class ErrorCodes(object):
             MerchantAccountIsSuspended = "94205"
             MerchantAccountIsForbidden = "94206"
             MerchantAccountCannotBeSubMerchantAccount = "94208"
+            AccountTypeIsInvalid = "942184"
+            AccountTypeNotSupported = "942185"
 
     class PaymentMethod(object):
         CannotForwardPaymentMethodType = "93106"
@@ -470,6 +476,7 @@ class ErrorCodes(object):
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
         AmountMustBeGreaterThanZero = "81531"
+        AmountNotSupportedByProcessor = "815193"
         BillingAddressConflict = "91530"
         CannotBeVoided = "91504"
         CannotCancelRelease = "91562"
@@ -578,6 +585,9 @@ class ErrorCodes(object):
         ThreeDSecureCavvIsRequired = "915116"
         ThreeDSecureXidIsRequired = "915115"
         ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureAuthenticationResponseIsInvalid = "915120"
+        ThreeDSecureDirectoryResponseIsInvalid = "915121"
+        ThreeDSecureCavvAlgorithmIsInvalid = "915122"
         ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         TooManyLineItems = "915157"
         LineItemsExpected = "915158"
@@ -602,7 +612,10 @@ class ErrorCodes(object):
 
             class PayPal(object):
                 CustomFieldTooLong = "91580"
-
+            class CreditCard(object):
+                AccountTypeIsInvalid = "915184"
+                AccountTypeNotSupported = "915185"
+                AccountTypeDebitDoesNotSupportAuths = "915186"
         class Industry(object):
             IndustryTypeIsInvalid = "93401"
 
@@ -613,6 +626,17 @@ class ErrorCodes(object):
                 CheckOutDateIsInvalid = "93405"
                 CheckOutDateMustFollowCheckInDate = "93406"
                 UnknownDataField = "93407"
+                RoomRateMustBeGreaterThanZero = "93433"
+                RoomRateFormatIsInvalid = "93434"
+                RoomRateIsTooLarge = "93435"
+                RoomTaxMustBeGreaterThanZero = "93436"
+                RoomTaxFormatIsInvalid = "93437"
+                RoomTaxIsTooLarge = "93438"
+                NoShowIndicatorIsInvalid = "93439"
+                AdvancedDepositIndicatorIsInvalid = "93440"
+                FireSafetyIndicatorIsInvalid = "93441"
+                PropertyPhoneIsInvalid = "93442"
+
             class TravelCruise(object):
                 EmptyData = "93408"
                 UnknownDataField = "93409"
@@ -664,6 +688,14 @@ class ErrorCodes(object):
                     TaxAmountIsTooLarge = "96319"
                     TicketNumberIsTooLong = "96320"
 
+            class AdditionalCharge(object):
+                KindIsInvalid = "96601"
+                KindMustBeUnique = "96602"
+                AmountMustBeGreaterThanZero = "96603"
+                AmountFormatIsInvalid = "96604"
+                AmountIsTooLarge = "96605"
+                AmountIsRequired = "96606"
+
         class LineItem(object):
             CommodityCodeIsTooLong = "95801"
             DescriptionIsTooLong = "95803"
