@@ -4,6 +4,6 @@ class DownForMaintenanceError(BraintreeError):
     """
     Raised when the gateway is down for maintenance.
 
-    See https://developers.braintreepayments.com/python/reference/general/error-handling/exceptions#down-for-maintenance-error
+    See https://developers.braintreepayments.com/reference/general/exceptions/python#down-for-maintenance
     """
     pass
