@@ -17,6 +17,8 @@ class Nonces(object):
     AndroidPayCardAmEx = "fake-android-pay-amex-nonce"
     AmexExpressCheckoutCard = "fake-amex-express-checkout-nonce"
     VenmoAccount = "fake-venmo-account-nonce"
+    VenmoAccountTokenIssuanceError = "fake-token-issuance-error-venmo-account-nonce"
+    ThreeDSecureVisaFullAuthentication = "fake-three-d-secure-visa-full-authentication-nonce"
     TransactableVisa = "fake-valid-visa-nonce"
     TransactableAmEx = "fake-valid-amex-nonce"
     TransactableMasterCard = "fake-valid-mastercard-nonce"
@@ -40,6 +42,7 @@ class Nonces(object):
     ProcessorDeclinedAmEx = "fake-processor-declined-amex-nonce"
     ProcessorDeclinedDiscover = "fake-processor-declined-discover-nonce"
     ProcessorFailureJCB = "fake-processor-failure-jcb-nonce"
+    LocalPayment = "fake-local-payment-method-nonce"
     LuhnInvalid = "fake-luhn-invalid-nonce"
     PayPalFuturePaymentRefreshToken = "fake-paypal-future-refresh-token-nonce"
     SEPA = "fake-sepa-bank-account-nonce"
