@@ -3,6 +3,7 @@ import warnings
 from decimal import Decimal
 from braintree.add_on import AddOn
 from braintree.apple_pay_card import ApplePayCard
+from braintree.authorization_adjustment import AuthorizationAdjustment
 from braintree.coinbase_account import CoinbaseAccount
 from braintree.android_pay_card import AndroidPayCard
 from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
@@ -19,6 +20,7 @@ from braintree.configuration import Configuration
 from braintree.credit_card import CreditCard
 from braintree.customer import Customer
 from braintree.paypal_account import PayPalAccount
+from braintree.paypal_here import PayPalHere
 from braintree.europe_bank_account import EuropeBankAccount
 from braintree.subscription_details import SubscriptionDetails
 from braintree.resource_collection import ResourceCollection
@@ -27,9 +29,18 @@ from braintree.exceptions.not_found_error import NotFoundError
 from braintree.descriptor import Descriptor
 from braintree.risk_data import RiskData
 from braintree.three_d_secure_info import ThreeDSecureInfo
+from braintree.transaction_line_item import TransactionLineItem
 from braintree.us_bank_account import UsBankAccount
+# NEXT_MAJOR_VERSION Remove this class as legacy Ideal has been removed/disabled in the Braintree Gateway
+# DEPRECATED If you're looking to accept iDEAL as a payment method contact accounts@braintreepayments.com for a solution.
+from braintree.ideal_payment import IdealPayment
+from braintree.local_payment import LocalPayment
+from braintree.visa_checkout_card import VisaCheckoutCard
+from braintree.masterpass_card import MasterpassCard
+from braintree.facilitated_details import FacilitatedDetails
 from braintree.facilitator_details import FacilitatorDetails
 from braintree.payment_instrument_type import PaymentInstrumentType
+from braintree.samsung_pay_card import SamsungPayCard
 
 class Transaction(Resource):
     """
@@ -91,6 +102,8 @@ class Transaction(Resource):
         "id",
         "additional_processor_response",
         "amount",
+        "authorization_adjustments",
+        "authorization_expires_at",
         "avs_error_response_code",
         "avs_postal_code_response_code",
         "avs_street_address_response_code",
@@ -100,11 +113,15 @@ class Transaction(Resource):
         "currency_iso_code",
         "customer_id",
         "cvv_response_code",
+        "discount_amount",
         "disputes",
         "escrow_status",
         "gateway_rejection_reason",
         "master_merchant_account_id",
         "merchant_account_id",
+        "network_response_code",
+        "network_response_text",
+        "network_transaction_id",
         "order_id",
         "payment_instrument_type",
         "payment_method_token",
@@ -120,6 +137,8 @@ class Transaction(Resource):
         "refunded_transaction_id",
         "service_fee_amount",
         "settlement_batch_id",
+        "shipping_amount",
+        "ships_from_postal_code",
         "status",
         "status_history",
         "sub_merchant_account_id",
@@ -163,6 +182,7 @@ class Transaction(Resource):
         Duplicate             = "duplicate"
         Fraud                 = "fraud"
         ThreeDSecure          = "three_d_secure"
+        TokenIssuance         = "token_issuance"
         Unrecognized          = "unrecognized"
 
     class Source(object):
@@ -193,16 +213,18 @@ class Transaction(Resource):
         """
         Constants representing transaction statuses. Available statuses are:
 
+        * braintree.Transaction.Status.AuthorizationExpired
         * braintree.Transaction.Status.Authorized
         * braintree.Transaction.Status.Authorizing
+        * braintree.Transaction.Status.SettlementPending
+        * braintree.Transaction.Status.SettlementDeclined
         * braintree.Transaction.Status.Failed
         * braintree.Transaction.Status.GatewayRejected
         * braintree.Transaction.Status.ProcessorDeclined
         * braintree.Transaction.Status.Settled
-        * braintree.Transaction.Status.SettlementFailed
         * braintree.Transaction.Status.Settling
         * braintree.Transaction.Status.SubmittedForSettlement
-        * braintree.Transaction.Status.Void
+        * braintree.Transaction.Status.Voided
         """
 
         AuthorizationExpired   = "authorization_expired"
@@ -219,6 +241,7 @@ class Transaction(Resource):
         Settling               = "settling"
         SubmittedForSettlement = "submitted_for_settlement"
         Voided                 = "voided"
+        # NEXT_MAJOR_VERSION this is never used and should be removed
         Unrecognized           = "unrecognized"
 
     class Type(object):
@@ -235,6 +258,15 @@ class Transaction(Resource):
     class IndustryType(object):
         Lodging = "lodging"
         TravelAndCruise = "travel_cruise"
+        TravelAndFlight = "travel_flight"
+
+    class AdditionalCharge(object):
+        Restaurant = "restaurant"
+        GiftShop = "gift_shop"
+        MiniBar = "mini_bar"
+        Telephone = "telephone"
+        Laundry = "laundry"
+        Other = "other"
 
     @staticmethod
     def clone_transaction(transaction_id, params):
@@ -307,6 +339,13 @@ class Transaction(Resource):
         """
         return Configuration.gateway().transaction.find(transaction_id)
 
+    @staticmethod
+    def line_items(transaction_id):
+        """
+        Find a transaction's line items, given a transaction_id. This does not return
+        a result object. This will raise a :class:`NotFoundError <braintree.exceptions.not_found_error.NotFoundError>` if the provided transaction_id is not found. ::
+        """
+        return Configuration.gateway().transaction_line_item.find_all(transaction_id)
 
     @staticmethod
     def hold_in_escrow(transaction_id):
@@ -488,7 +527,8 @@ class Transaction(Resource):
             "amount", "customer_id", "device_session_id", "fraud_merchant_id", "merchant_account_id", "order_id", "channel",
             "payment_method_token", "purchase_order_number", "recurring", "transaction_source", "shipping_address_id",
             "device_data", "billing_address_id", "payment_method_nonce", "tax_amount",
-            "shared_payment_method_token", "shared_customer_id", "shared_billing_address_id", "shared_shipping_address_id",
+            "shared_payment_method_token", "shared_customer_id", "shared_billing_address_id", "shared_shipping_address_id", "shared_payment_method_nonce",
+            "discount_amount", "shipping_amount", "ships_from_postal_code",
             "tax_exempt", "three_d_secure_token", "type", "venmo_sdk_payment_method_code", "service_fee_amount",
             {
                 "risk_data": [
@@ -523,7 +563,12 @@ class Transaction(Resource):
                 "three_d_secure_pass_thru": [
                     "eci_flag",
                     "cavv",
-                    "xid"
+                    "xid",
+                    "authentication_response",
+                    "directory_response",
+                    "cavv_algorithm",
+                    "ds_transaction_id",
+                    "three_d_secure_version"
                 ]
             },
             {
@@ -535,9 +580,17 @@ class Transaction(Resource):
                     "store_shipping_address_in_vault",
                     "submit_for_settlement",
                     "venmo_sdk_session",
+                    "payee_id",
                     "payee_email",
+                    "skip_advanced_fraud_checking",
+                    "skip_avs",
+                    "skip_cvv",
                     {
+                        "credit_card": [
+                            "account_type"
+                        ],
                         "paypal": [
+                            "payee_id",
                             "payee_email",
                             "custom_field",
                             "description",
@@ -555,7 +608,11 @@ class Transaction(Resource):
                         "venmo_merchant_data": [
                             "venmo_merchant_public_id",
                             "originating_transaction_id",
-                            "originating_merchant_id"
+                            "originating_merchant_id",
+                            "originating_merchant_kind"
+                        ],
+                        "venmo": [
+                            "profile_id"
                         ],
                     },
                     {
@@ -567,19 +624,38 @@ class Transaction(Resource):
                 ]
             },
             {"custom_fields": ["__any_key__"]},
+            {"external_vault": ["status", "previous_network_transaction_id"]},
             {"descriptor": ["name", "phone", "url"]},
-            {"paypal_account": ["payee_email"]},
+            {"paypal_account": ["payee_id", "payee_email", "payer_id", "payment_id"]},
             {"industry":
                 [
                     "industry_type",
                     {
                         "data": [
-                            "folio_number", "check_in_date", "check_out_date", "departure_date", "lodging_check_in_date", "lodging_check_out_date", "travel_package", "lodging_name", "room_rate"
-                            ]
-                        }
-                    ]
-                }
-            ]
+                            "folio_number", "check_in_date", "check_out_date", "departure_date", "lodging_check_in_date", "lodging_check_out_date", "travel_package", "lodging_name", "room_rate",
+                            "passenger_first_name", "passenger_last_name", "passenger_middle_initial", "passenger_title", "issued_date", "travel_agency_name", "travel_agency_code", "ticket_number",
+                            "issuing_carrier_code", "customer_code", "fare_amount", "fee_amount", "room_tax", "tax_amount", "restricted_ticket", "no_show", "advanced_deposit", "fire_safe", "property_phone",
+                            {
+                                "legs": [
+                                    "conjunction_ticket", "exchange_ticket", "coupon_number", "service_class", "carrier_code", "fare_basis_code", "flight_number", "departure_date", "departure_airport_code", "departure_time",
+                                    "arrival_airport_code", "arrival_time", "stopover_permitted", "fare_amount", "fee_amount", "tax_amount", "endorsement_or_restrictions"
+                                ]
+                            },
+                            {
+                                "additional_charges": [
+                                  "kind", "amount"
+                                ],
+                            }
+                        ]
+                    }
+                ]
+            },
+            {"line_items":
+                [
+                    "quantity", "name", "description", "kind", "unit_amount", "unit_tax_amount", "total_amount", "discount_amount", "tax_amount", "unit_of_measure", "product_code", "commodity_code", "url",
+                ]
+            },
+        ]
 
     @staticmethod
     def submit_for_settlement_signature():
@@ -616,18 +692,30 @@ class Transaction(Resource):
         Resource.__init__(self, gateway, attributes)
 
         self.amount = Decimal(self.amount)
-        if self.tax_amount:
+        if "tax_amount" in attributes and self.tax_amount:
             self.tax_amount = Decimal(self.tax_amount)
+        if "discount_amount" in attributes and self.discount_amount:
+            self.discount_amount = Decimal(self.discount_amount)
+        if "shipping_amount" in attributes and self.shipping_amount:
+            self.shipping_amount = Decimal(self.shipping_amount)
         if "billing" in attributes:
             self.billing_details = Address(gateway, attributes.pop("billing"))
         if "credit_card" in attributes:
             self.credit_card_details = CreditCard(gateway, attributes.pop("credit_card"))
         if "paypal" in attributes:
             self.paypal_details = PayPalAccount(gateway, attributes.pop("paypal"))
+        if "paypal_here" in attributes:
+            self.paypal_here_details = PayPalHere(gateway, attributes.pop("paypal_here"))
+        if "local_payment" in attributes:
+            self.local_payment_details = LocalPayment(gateway, attributes.pop("local_payment"))
         if "europe_bank_account" in attributes:
             self.europe_bank_account_details = EuropeBankAccount(gateway, attributes.pop("europe_bank_account"))
         if "us_bank_account" in attributes:
             self.us_bank_account = UsBankAccount(gateway, attributes.pop("us_bank_account"))
+        # NEXT_MAJOR_VERSION Remove this class as legacy Ideal has been removed/disabled in the Braintree Gateway
+        # DEPRECATED If you're looking to accept iDEAL as a payment method contact accounts@braintreepayments.com for a solution.
+        if "ideal_payment" in attributes:
+            self.ideal_payment_details = IdealPayment(gateway, attributes.pop("ideal_payment"))
         if "apple_pay" in attributes:
             self.apple_pay_details = ApplePayCard(gateway, attributes.pop("apple_pay"))
         if "coinbase_account" in attributes:
@@ -638,6 +726,12 @@ class Transaction(Resource):
             self.amex_express_checkout_card_details = AmexExpressCheckoutCard(gateway, attributes.pop("amex_express_checkout_card"))
         if "venmo_account" in attributes:
             self.venmo_account_details = VenmoAccount(gateway, attributes.pop("venmo_account"))
+        if "visa_checkout_card" in attributes:
+            self.visa_checkout_card_details = VisaCheckoutCard(gateway, attributes.pop("visa_checkout_card"))
+        if "masterpass_card" in attributes:
+            self.masterpass_card_details = MasterpassCard(gateway, attributes.pop("masterpass_card"))
+        if "samsung_pay_card" in attributes:
+            self.samsung_pay_card_details = SamsungPayCard(gateway, attributes.pop("samsung_pay_card"))
         if "customer" in attributes:
             self.customer_details = Customer(gateway, attributes.pop("customer"))
         if "shipping" in attributes:
@@ -656,6 +750,8 @@ class Transaction(Resource):
             self.disbursement_details = DisbursementDetail(attributes.pop("disbursement_details"))
         if "disputes" in attributes:
             self.disputes = [Dispute(dispute) for dispute in self.disputes]
+        if "authorization_adjustments" in attributes:
+            self.authorization_adjustments = [AuthorizationAdjustment(authorization_adjustment) for authorization_adjustment in self.authorization_adjustments]
         if "payment_instrument_type" in attributes:
             self.payment_instrument_type = attributes["payment_instrument_type"]
 
@@ -667,8 +763,12 @@ class Transaction(Resource):
             self.three_d_secure_info = ThreeDSecureInfo(attributes["three_d_secure_info"])
         else:
             self.three_d_secure_info = None
+        if "facilitated_details" in attributes:
+            self.facilitated_details = FacilitatedDetails(attributes.pop("facilitated_details"))
         if "facilitator_details" in attributes:
             self.facilitator_details = FacilitatorDetails(attributes.pop("facilitator_details"))
+        if "network_transaction_id" in attributes:
+            self.network_transaction_id = attributes["network_transaction_id"]
 
     @property
     def refund_id(self):
@@ -705,3 +805,9 @@ class Transaction(Resource):
     def is_disbursed(self):
        return self.disbursement_details.is_valid
 
+    @property
+    def line_items(self):
+        """
+        The line items associated with this transaction
+        """
+        return self.gateway.transaction_line_item.find_all(self.id)
