@@ -18,7 +18,7 @@ class TransactionGateway(object):
         return self._post("/transactions/" + transaction_id + "/clone", {"transaction-clone": params})
 
     def cancel_release(self, transaction_id):
-        response = self.config.http().put("/transactions/" + transaction_id + "/cancel_release", {})
+        response = self.config.http().put(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/cancel_release", {})
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
@@ -34,12 +34,12 @@ class TransactionGateway(object):
 
     def find(self, transaction_id):
         try:
-            if transaction_id == None or transaction_id.strip() == "":
+            if transaction_id is None or transaction_id.strip() == "":
                 raise NotFoundError()
-            response = self.config.http().get("/transactions/" + transaction_id)
+            response = self.config.http().get(self.config.base_merchant_path() + "/transactions/" + transaction_id)
             return Transaction(self.gateway, response["transaction"])
         except NotFoundError:
-            raise NotFoundError("transaction with id " + transaction_id + " not found")
+            raise NotFoundError("transaction with id " + repr(transaction_id) + " not found")
 
     def hold_in_escrow(self, transaction_id):
         """
@@ -48,45 +48,78 @@ class TransactionGateway(object):
             result = braintree.Transaction.hold_in_escrow("my_transaction_id")
         """
 
-        response = self.config.http().put("/transactions/" + transaction_id + "/hold_in_escrow", {})
+        response = self.config.http().put(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/hold_in_escrow", {})
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
             return ErrorResult(self.gateway, response["api_error_response"])
 
-    def refund(self, transaction_id, amount=None):
+    def refund(self, transaction_id, amount_or_options=None):
         """
         Refunds an existing transaction. It expects a transaction_id. ::
 
             result = braintree.Transaction.refund("my_transaction_id")
         """
-
-        response = self.config.http().post("/transactions/" + transaction_id + "/refund", {"transaction": {"amount": amount}})
+        if isinstance(amount_or_options, dict):
+            options = amount_or_options
+        else:
+            options = {
+                "amount": amount_or_options
+            }
+        Resource.verify_keys(options, Transaction.refund_signature())
+        response = self.config.http().post(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/refund", {"transaction": options})
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
             return ErrorResult(self.gateway, response["api_error_response"])
 
+    def sale(self, params):
+        params.update({"type": "sale"})
+        return self.create(params)
+
     def search(self, *query):
         if isinstance(query[0], list):
             query = query[0]
 
-        response = self.config.http().post("/transactions/advanced_search_ids", {"search": self.__criteria(query)})
+        response = self.config.http().post(self.config.base_merchant_path() + "/transactions/advanced_search_ids", {"search": self.__criteria(query)})
         if "search_results" in response:
             return ResourceCollection(query, response, self.__fetch)
         else:
             raise DownForMaintenanceError("search timeout")
 
     def release_from_escrow(self, transaction_id):
-        response = self.config.http().put("/transactions/" + transaction_id + "/release_from_escrow", {})
+        response = self.config.http().put(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/release_from_escrow", {})
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
             return ErrorResult(self.gateway, response["api_error_response"])
 
-    def submit_for_settlement(self, transaction_id, amount=None):
-        response = self.config.http().put("/transactions/" + transaction_id + "/submit_for_settlement",
-                {"transaction": {"amount": amount}})
+    def submit_for_settlement(self, transaction_id, amount=None, params={}):
+        Resource.verify_keys(params, Transaction.submit_for_settlement_signature())
+        transaction_params = {"amount": amount}
+        transaction_params.update(params)
+        response = self.config.http().put(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/submit_for_settlement",
+                {"transaction": transaction_params})
+        if "transaction" in response:
+            return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
+        elif "api_error_response" in response:
+            return ErrorResult(self.gateway, response["api_error_response"])
+
+    def update_details(self, transaction_id, params={}):
+        Resource.verify_keys(params, Transaction.update_details_signature())
+        response = self.config.http().put(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/update_details",
+                {"transaction": params})
+        if "transaction" in response:
+            return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
+        elif "api_error_response" in response:
+            return ErrorResult(self.gateway, response["api_error_response"])
+
+    def submit_for_partial_settlement(self, transaction_id, amount, params={}):
+        Resource.verify_keys(params, Transaction.submit_for_settlement_signature())
+        transaction_params = {"amount": amount}
+        transaction_params.update(params)
+        response = self.config.http().post(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/submit_for_partial_settlement",
+                {"transaction": transaction_params})
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
@@ -109,10 +142,10 @@ class TransactionGateway(object):
         return self.gateway.transparent_redirect.tr_data(tr_data, redirect_url)
 
     def transparent_redirect_create_url(self):
-        return self.config.base_merchant_url() + "/transactions/all/create_via_transparent_redirect_request"
+        return self.config.base_url() + self.config.base_merchant_path() + "/transactions/all/create_via_transparent_redirect_request"
 
     def void(self, transaction_id):
-        response = self.config.http().put("/transactions/" + transaction_id + "/void")
+        response = self.config.http().put(self.config.base_merchant_path() + "/transactions/" + transaction_id + "/void")
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
@@ -121,8 +154,11 @@ class TransactionGateway(object):
     def __fetch(self, query, ids):
         criteria = self.__criteria(query)
         criteria["ids"] = braintree.transaction_search.TransactionSearch.ids.in_list(ids).to_param()
-        response = self.config.http().post("/transactions/advanced_search", {"search": criteria})
-        return [Transaction(self.gateway, item) for item in  ResourceCollection._extract_as_array(response["credit_card_transactions"], "transaction")]
+        response = self.config.http().post(self.config.base_merchant_path() + "/transactions/advanced_search", {"search": criteria})
+        if "credit_card_transactions" in response:
+            return [Transaction(self.gateway, item) for item in ResourceCollection._extract_as_array(response["credit_card_transactions"], "transaction")]
+        else:
+            raise DownForMaintenanceError("search timeout")
 
     def __criteria(self, query):
         criteria = {}
@@ -134,7 +170,7 @@ class TransactionGateway(object):
         return criteria
 
     def _post(self, url, params={}):
-        response = self.config.http().post(url, params)
+        response = self.config.http().post(self.config.base_merchant_path() + url, params)
         if "transaction" in response:
             return SuccessfulResult({"transaction": Transaction(self.gateway, response["transaction"])})
         elif "api_error_response" in response:
