@@ -5,10 +5,10 @@ class TestVerificationSearch(unittest.TestCase):
     def test_advanced_search_no_results(self):
         collection = CreditCardVerification.search([
             CreditCardVerificationSearch.credit_card_cardholder_name == "no such person"])
-        self.assertEquals(0, collection.maximum_size)
+        self.assertEqual(0, collection.maximum_size)
 
     def test_search_on_verification_id(self):
-        customer_id = "%s" % randint(1, 10000)
+        customer_id = "%s" % random.randint(1, 10000)
 
         result = Customer.create({
             "id": customer_id,
@@ -31,8 +31,8 @@ class TestVerificationSearch(unittest.TestCase):
 
     def test_all_text_fields(self):
         email = "mark.a@example.com"
-        cardholder_name = "Tom %s" % randint(1, 10000)
-        customer_id = "%s" % randint(1, 10000)
+        cardholder_name = "Tom %s" % random.randint(1, 10000)
+        customer_id = "%s" % random.randint(1, 10000)
         expiration_date = "10/2012"
         number = CreditCardNumbers.MasterCard
         postal_code = "44444"
@@ -66,7 +66,7 @@ class TestVerificationSearch(unittest.TestCase):
         self.assertEqual(customer.credit_cards[0].token, found_verifications.first.credit_card["token"])
 
     def test_multiple_value_fields(self):
-        cardholder_name = "Tom %s" % randint(1, 10000)
+        cardholder_name = "Tom %s" % random.randint(1, 10000)
         number = CreditCardNumbers.FailsSandboxVerification.MasterCard
         unsuccessful_result1 = Customer.create({"credit_card": {
             "cardholder_name": cardholder_name,
@@ -75,7 +75,7 @@ class TestVerificationSearch(unittest.TestCase):
             "options": {"verify_card": True}
         }})
 
-        cardholder_name = "Tom %s" % randint(1, 10000)
+        cardholder_name = "Tom %s" % random.randint(1, 10000)
         number = CreditCardNumbers.FailsSandboxVerification.Visa
         unsuccessful_result2 = Customer.create({"credit_card": {
             "cardholder_name": cardholder_name,
@@ -96,10 +96,10 @@ class TestVerificationSearch(unittest.TestCase):
                     verification1.status, verification2.status])
         )
 
-        self.assertEquals(2, search_results.maximum_size)
+        self.assertEqual(2, search_results.maximum_size)
 
     def test_range_field(self):
-        cardholder_name = "Tom %s" % randint(1, 10000)
+        cardholder_name = "Tom %s" % random.randint(1, 10000)
         number = CreditCardNumbers.FailsSandboxVerification.MasterCard
         unsuccessful_result = Customer.create({"credit_card": {
             "cardholder_name": cardholder_name,
@@ -116,7 +116,7 @@ class TestVerificationSearch(unittest.TestCase):
                 CreditCardVerificationSearch.id == created_verification.id,
                 CreditCardVerificationSearch.created_at.between(before_creation, after_creation))
 
-        self.assertEquals(1, found_verifications.maximum_size)
+        self.assertEqual(1, found_verifications.maximum_size)
 
         way_before_creation = created_time - timedelta(minutes=10)
         just_before_creation = created_time - timedelta(minutes=1)
@@ -124,11 +124,10 @@ class TestVerificationSearch(unittest.TestCase):
                 CreditCardVerificationSearch.id == created_verification.id,
                 CreditCardVerificationSearch.created_at.between(way_before_creation, just_before_creation))
 
-        self.assertEquals(0, found_verifications.maximum_size)
+        self.assertEqual(0, found_verifications.maximum_size)
 
         found_verifications = CreditCardVerification.search(
                 CreditCardVerificationSearch.id == created_verification.id,
                 CreditCardVerificationSearch.created_at == created_time)
 
-        self.assertEquals(1, found_verifications.maximum_size)
-
+        self.assertEqual(1, found_verifications.maximum_size)
