@@ -10,7 +10,8 @@ class TestHttp(unittest.TestCase):
     else:
         SSLError = requests.models.SSLError
 
-    def get_http(self, environment):
+    @staticmethod
+    def get_http(environment):
         config = Configuration(environment, "merchant_id", public_key="public_key", private_key="private_key")
         return config.http()
 
@@ -39,7 +40,7 @@ class TestHttp(unittest.TestCase):
             gateway.transaction.find("my_id")
         except braintree.exceptions.unexpected_error.UnexpectedError:
             correct_exception = True
-        except Exception as e:
+        except Exception:
             correct_exception = False
 
         self.assertTrue(correct_exception)
@@ -48,7 +49,8 @@ class TestHttp(unittest.TestCase):
         if platform.system() == "Darwin":
             return
 
-        environment = Environment("test", "www.google.com", "443", "http://auth.venmo.dev:9292", True, Environment.Production.ssl_certificate)
+        #any endpoint that returns valid XML with a status of 3xx or less and serves SSL
+        environment = Environment("test", "aws.amazon.com/ec2", "443", "http://auth.venmo.dev:9292", True, Environment.Production.ssl_certificate)
         http = self.get_http(environment)
         try:
             http.get("/")
@@ -65,7 +67,7 @@ class TestHttp(unittest.TestCase):
         http = self.get_http(environment)
         try:
             http.get("/")
-        except self.SSLError as e:
+        except self.SSLError:
             pass
         else:
             self.fail("Expected to receive an SSL error but no exception was raised")
@@ -86,7 +88,7 @@ class TestHttp(unittest.TestCase):
             gateway.transaction.find("my_id")
         except braintree.exceptions.http.timeout_error.TimeoutError:
             correct_exception = True
-        except Exception as e:
+        except Exception:
             correct_exception = False
 
         self.assertTrue(correct_exception)
