@@ -48,7 +48,7 @@ class TestCreditCard(unittest.TestCase):
                     "extended_address", "first_name", "last_name", "locality", "postal_code", "region", "street_address"
                 ]
             },
-            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session", "fail_on_duplicate_payment_method", {"adyen":["overwrite_brand", "selected_brand"]}
+            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "verification_account_type", "venmo_sdk_session", "fail_on_duplicate_payment_method", {"adyen":["overwrite_brand", "selected_brand"]}
             ]},
             "customer_id"
         ]
@@ -65,7 +65,7 @@ class TestCreditCard(unittest.TestCase):
                     {"options": ["update_existing"]}
                 ]
             },
-            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session", "fail_on_duplicate_payment_method", {"adyen":["overwrite_brand", "selected_brand"]}
+            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "verification_account_type", "venmo_sdk_session", "fail_on_duplicate_payment_method", {"adyen":["overwrite_brand", "selected_brand"]}
             ]}
         ]
         self.assertEqual(expected, CreditCard.update_signature())
@@ -78,6 +78,14 @@ class TestCreditCard(unittest.TestCase):
     def test_finding_none_raises_not_found_exception(self):
         CreditCard.find(None)
 
+    @raises(NotFoundError)
+    def test_from_nonce_empty_id_raises_not_found_exception(self):
+        CreditCard.from_nonce(" ")
+
+    @raises(NotFoundError)
+    def test_from_nonce_none_raises_not_found_exception(self):
+        CreditCard.from_nonce(None)
+
     def test_multiple_verifications_sort(self):
         verification1 = {"created_at": datetime.datetime(2014, 11, 18, 23, 20, 20), "id": 123, "amount": "0.00"}
         verification2 = {"created_at": datetime.datetime(2014, 11, 18, 23, 20, 21), "id": 456, "amount": "1.00"}
