@@ -1,6 +1,9 @@
 from tests.test_helper import *
 from datetime import date
 from braintree.dispute import Dispute
+from braintree.credit_card import CreditCard
+from braintree.paypal_account import PayPalAccount
+from braintree.venmo_account import VenmoAccount
 
 class TestWebhooks(unittest.TestCase):
     def test_sample_notification_builds_a_parsable_notification(self):
@@ -464,56 +467,167 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual("link-to-csv-report", notification.account_updater_daily_report.report_url)
         self.assertEqual(date(2016, 1, 14), notification.account_updater_daily_report.report_date)
 
-    def test_ideal_payment_complete_webhook(self):
+    def test_grantor_updated_granted_payment_method_webhook(self):
         sample_notification = WebhookTesting.sample_notification(
-            WebhookNotification.Kind.IdealPaymentComplete,
-            "my_id"
-        )
-
-        notification = WebhookNotification.parse(sample_notification['bt_signature'], sample_notification['bt_payload'])
-        ideal_payment = notification.ideal_payment
-
-        self.assertEqual(WebhookNotification.Kind.IdealPaymentComplete, notification.kind)
-        self.assertEqual("my_id", ideal_payment.id)
-        self.assertEqual("COMPLETE", ideal_payment.status);
-        self.assertEqual("ORDERABC", ideal_payment.order_id);
-        self.assertEqual("10.00", ideal_payment.amount);
-        self.assertEqual("https://example.com", ideal_payment.approval_url);
-        self.assertEqual("1234567890", ideal_payment.ideal_transaction_id);
-
-    def test_ideal_payment_failed_webhook(self):
-        sample_notification = WebhookTesting.sample_notification(
-            WebhookNotification.Kind.IdealPaymentFailed,
-            "my_id"
-        )
-
-        notification = WebhookNotification.parse(sample_notification['bt_signature'], sample_notification['bt_payload'])
-        ideal_payment = notification.ideal_payment
-
-        self.assertEqual(WebhookNotification.Kind.IdealPaymentFailed, notification.kind)
-        self.assertEqual("my_id", ideal_payment.id)
-        self.assertEqual("FAILED", ideal_payment.status);
-        self.assertEqual("ORDERABC", ideal_payment.order_id);
-        self.assertEqual("10.00", ideal_payment.amount);
-        self.assertEqual("https://example.com", ideal_payment.approval_url);
-        self.assertEqual("1234567890", ideal_payment.ideal_transaction_id);
-
-    def test_granted_payment_instrument_update_webhook(self):
-        sample_notification = WebhookTesting.sample_notification(
-            WebhookNotification.Kind.GrantedPaymentInstrumentUpdate,
+            WebhookNotification.Kind.GrantorUpdatedGrantedPaymentMethod,
             "my_id"
         )
 
         notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
         update = notification.granted_payment_instrument_update
 
-        self.assertEqual(WebhookNotification.Kind.GrantedPaymentInstrumentUpdate, notification.kind)
+        self.assertEqual(WebhookNotification.Kind.GrantorUpdatedGrantedPaymentMethod, notification.kind)
         self.assertEqual("vczo7jqrpwrsi2px", update.grant_owner_merchant_id)
         self.assertEqual("cf0i8wgarszuy6hc", update.grant_recipient_merchant_id)
         self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", update.payment_method_nonce)
         self.assertEqual("abc123z", update.token)
         self.assertEqual(["expiration-month", "expiration-year"], update.updated_fields)
 
+    def test_recipient_updated_granted_payment_method_webhook(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.RecipientUpdatedGrantedPaymentMethod,
+            "my_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        update = notification.granted_payment_instrument_update
+
+        self.assertEqual(WebhookNotification.Kind.RecipientUpdatedGrantedPaymentMethod, notification.kind)
+        self.assertEqual("vczo7jqrpwrsi2px", update.grant_owner_merchant_id)
+        self.assertEqual("cf0i8wgarszuy6hc", update.grant_recipient_merchant_id)
+        self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", update.payment_method_nonce)
+        self.assertEqual("abc123z", update.token)
+        self.assertEqual(["expiration-month", "expiration-year"], update.updated_fields)
+
+    def test_granted_payment_method_revoked_credit_card_webhook(self):
+        xml_payload = """
+            <notification>
+                <source-merchant-id>12345</source-merchant-id>
+                <timestamp type="datetime">2018-10-10T22:46:41Z</timestamp>
+                <kind>granted_payment_method_revoked</kind>
+                <subject>
+                    <credit-card>
+                        <bin>555555</bin>
+                        <card-type>MasterCard</card-type>
+                        <cardholder-name>Amber Ankunding</cardholder-name>
+                        <commercial>Unknown</commercial>
+                        <country-of-issuance>Unknown</country-of-issuance>
+                        <created-at type="datetime">2018-10-10T22:46:41Z</created-at>
+                        <customer-id>credit_card_customer_id</customer-id>
+                        <customer-location>US</customer-location>
+                        <debit>Unknown</debit>
+                        <default type="boolean">true</default>
+                        <durbin-regulated>Unknown</durbin-regulated>
+                        <expiration-month>06</expiration-month>
+                        <expiration-year>2020</expiration-year>
+                        <expired type="boolean">false</expired>
+                        <global-id>cGF5bWVudG1ldGhvZF8zcHQ2d2hz</global-id>
+                        <healthcare>Unknown</healthcare>
+                        <image-url>https://assets.braintreegateway.com/payment_method_logo/mastercard.png?environment=test</image-url>
+                        <issuing-bank>Unknown</issuing-bank>
+                        <last-4>4444</last-4>
+                        <payroll>Unknown</payroll>
+                        <prepaid>Unknown</prepaid>
+                        <product-id>Unknown</product-id>
+                        <subscriptions type="array"/>
+                        <token>credit_card_token</token>
+                        <unique-number-identifier>08199d188e37460163207f714faf074a</unique-number-identifier>
+                        <updated-at type="datetime">2018-10-10T22:46:41Z</updated-at>
+                        <venmo-sdk type="boolean">false</venmo-sdk>
+                        <verifications type="array"/>
+                    </credit-card>
+                </subject>
+            </notification>
+            """.encode("utf-8")
+        sample_notification = TestHelper.sample_notification_from_xml(xml_payload)
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        metadata = notification.revoked_payment_method_metadata
+
+        self.assertEqual(WebhookNotification.Kind.GrantedPaymentMethodRevoked, notification.kind)
+        self.assertEqual("credit_card_customer_id", metadata.customer_id)
+        self.assertEqual("credit_card_token", metadata.token)
+        self.assertTrue(isinstance(metadata.revoked_payment_method, CreditCard))
+
+    def test_granted_payment_method_revoked_paypal_account_webhook(self):
+        xml_payload = """
+            <notification>
+                <source-merchant-id>12345</source-merchant-id>
+                <timestamp type="datetime">2018-10-10T22:46:41Z</timestamp>
+                <kind>granted_payment_method_revoked</kind>
+                <subject>
+                    <paypal-account>
+                        <billing-agreement-id>billing_agreement_id</billing-agreement-id>
+                        <created-at type="dateTime">2018-10-11T21:10:33Z</created-at>
+                        <customer-id>paypal_customer_id</customer-id>
+                        <default type="boolean">true</default>
+                        <email>johndoe@example.com</email>
+                        <global-id>cGF5bWVudG1ldGhvZF9wYXlwYWxfdG9rZW4</global-id>
+                        <image-url>https://assets.braintreegateway.com/payment_method_logo/mastercard.png?environment=test</image-url>
+                        <subscriptions type="array"></subscriptions>
+                        <token>paypal_token</token>
+                        <updated-at type="dateTime">2018-10-11T21:10:33Z</updated-at>
+                        <payer-id>a6a8e1a4</payer-id>
+                    </paypal-account>
+                </subject>
+            </notification>
+            """.encode("utf-8")
+        sample_notification = TestHelper.sample_notification_from_xml(xml_payload)
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        metadata = notification.revoked_payment_method_metadata
+
+        self.assertEqual(WebhookNotification.Kind.GrantedPaymentMethodRevoked, notification.kind)
+        self.assertEqual("paypal_customer_id", metadata.customer_id)
+        self.assertEqual("paypal_token", metadata.token)
+        self.assertTrue(isinstance(metadata.revoked_payment_method, PayPalAccount))
+
+    def test_granted_payment_method_revoked_venmo_account_webhook(self):
+        xml_payload = """
+            <notification>
+                <source-merchant-id>12345</source-merchant-id>
+                <timestamp type="datetime">2018-10-10T22:46:41Z</timestamp>
+                <kind>granted_payment_method_revoked</kind>
+                <subject>
+                    <venmo-account>
+                        <created-at type="dateTime">2018-10-11T21:28:37Z</created-at>
+                        <updated-at type="dateTime">2018-10-11T21:28:37Z</updated-at>
+                        <default type="boolean">true</default>
+                        <image-url>https://assets.braintreegateway.com/payment_method_logo/mastercard.png?environment=test</image-url>
+                        <token>venmo_token</token>
+                        <source-description>Venmo Account: venmojoe</source-description>
+                        <username>venmojoe</username>
+                        <venmo-user-id>456</venmo-user-id>
+                        <subscriptions type="array"/>
+                        <customer-id>venmo_customer_id</customer-id>
+                        <global-id>cGF5bWVudG1ldGhvZF92ZW5tb2FjY291bnQ</global-id>
+                    </venmo-account>
+                </subject>
+            </notification>
+            """.encode("utf-8")
+        sample_notification = TestHelper.sample_notification_from_xml(xml_payload)
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        metadata = notification.revoked_payment_method_metadata
+
+        self.assertEqual(WebhookNotification.Kind.GrantedPaymentMethodRevoked, notification.kind)
+        self.assertEqual("venmo_customer_id", metadata.customer_id)
+        self.assertEqual("venmo_token", metadata.token)
+        self.assertTrue(isinstance(metadata.revoked_payment_method, VenmoAccount))
+
+    def test_payment_method_revoked_by_customer_webhook(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.PaymentMethodRevokedByCustomer,
+            "my_payment_method_token"
+        )
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        metadata = notification.revoked_payment_method_metadata
+
+        self.assertEqual(WebhookNotification.Kind.PaymentMethodRevokedByCustomer, notification.kind)
+        self.assertEqual("my_payment_method_token", metadata.token)
+        self.assertTrue(isinstance(metadata.revoked_payment_method, PayPalAccount))
+        self.assertNotEqual(None, metadata.revoked_payment_method.revoked_at)
+
     def test_local_payment_completed_webhook(self):
         sample_notification = WebhookTesting.sample_notification(
             WebhookNotification.Kind.LocalPaymentCompleted,
@@ -526,4 +640,6 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual(WebhookNotification.Kind.LocalPaymentCompleted, notification.kind)
         self.assertEqual("a-payment-id", local_payment_completed.payment_id)
         self.assertEqual("a-payer-id", local_payment_completed.payer_id)
+        self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", local_payment_completed.payment_method_nonce)
+        self.assertTrue(isinstance(local_payment_completed.transaction, Transaction))
 
